@@ -154,13 +154,13 @@ class Precursor():
 
 			for index, line in enumerate(arc.readlines()):
 
-				info = line[:-1].upper().replace(' ', '').replace('N', '').split('\t')
+				info = line[:-1].upper().replace(' ', '').replace('N', '').replace('T', 'U').split('\t')
 
 				if len(info) < 2 or len(info) > 4:
 
 					raise Exception("There was an error parsing your file {} at line {}".format(filename, index+1))
 
-				annot = set(info[1]) - set('ACTG')
+				annot = set(info[0]) - set('ACUG')
 
 				if annot:
 
